@@ -1,10 +1,11 @@
 use strict;
 use warnings;
-package DZT::Sample;
- 
+package     # hidden from PAUSE
+    DZT::Sample;
+
 sub return_arrayref_of_values_passed {
   my $invocant = shift;
   return \@_;
 }
-   
+
 1;
