@@ -1,9 +1,10 @@
 package Dist::Zilla::Plugin::CheckChangeLog;
-$Dist::Zilla::Plugin::CheckChangeLog::VERSION = '0.04';
+$Dist::Zilla::Plugin::CheckChangeLog::VERSION = '0.05';
 # ABSTRACT: Dist::Zilla with Changes check
 
 use 5.004;
 use Moose;
+
 with 'Dist::Zilla::Role::AfterBuild';
 
 has filename => (
@@ -15,13 +16,13 @@ sub after_build {
     my ($self, $args) = @_;
 
     my $root     = $args->{build_root};
-    my $filename = chomp $self->{filename};
+    my $filename = $self->{filename};
     my @change_files;
 
     if ($filename) {
-        my $file = $self->zilla->root->file($filename);
-        die "[CheckChangeLog] $! $filename\n" unless -e $file;
-        push @change_files, Dist::Zilla::File::OnDisk->new({name => $file});
+        chomp($filename);
+        die "[CheckChangeLog] $! $filename\n" unless -e $filename;
+        push @change_files, Dist::Zilla::File::OnDisk->new({name => $filename});
     } else {
         # Search for Changes or ChangeLog on build root
         my @files = $self->_find_change_files($root);
@@ -88,7 +89,7 @@ Dist::Zilla::Plugin::CheckChangeLog - Dist::Zilla with Changes check
 
 =head1 VERSION
 
-version 0.04
+version 0.05
 
 =head1 SYNOPSIS
 
